@@ -44,7 +44,7 @@ use WebDyne::Request::Fake;
 
 #  Version information
 #
-$VERSION='2.028';
+$VERSION='2.029';
 
 
 #  Debug load
@@ -199,10 +199,10 @@ sub lookup_file {
 
     my ($r, $fn)=@_;
     my $r_child;
-    ##if ($fn!~/\.psp$/) {
+    if ($fn!~/\.psp$/) { # fastest
     #if ($fn=~/\.html$/) {
     #  If not psp file serve as static
-    unless (substr($fn, -WEBDYNE_PSP_EXT_LEN) eq WEBDYNE_PSP_EXT) {
+    #unless (substr($fn, -WEBDYNE_PSP_EXT_LEN) eq WEBDYNE_PSP_EXT) {
 
 
         #  Static file
@@ -299,8 +299,8 @@ sub new {
             #  Need to add default psp file ?
             #
             #if ($fn=~/\/$/) {
-            #unless ($fn=~/\.psp$/) {
-            unless (substr($fn, -WEBDYNE_PSP_EXT_LEN ) eq WEBDYNE_PSP_EXT ) {
+            unless ($fn=~/\.psp$/) { # fastest
+            #unless (substr($fn, -WEBDYNE_PSP_EXT_LEN ) eq WEBDYNE_PSP_EXT ) {
 
                 #  Is it a directory that exists ? Only append default document if that is the case, else let the api code
                 #  handle it
